## 全国拍摄制作电视剧备案公示数据

接口：teleplay_record

描述：获取2009年以来全国拍摄制作电视剧备案公示数据

限量：单次最大1000，总量不限制

数据权限：用户需要至少积分600才可以调取，积分越多调取频次越高，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| report_date | str | N | 备案月份（YYYYMM） |
| start_date | str | N | 备案开始月份（YYYYMM） |
| end_date | str | N | 备案结束月份（YYYYMM） |
| org | str | N | 备案机构 |
| name | str | N | 电视剧名称 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| name | str | Y | 电视剧名称 |
| classify | str | Y | 题材 |
| types | str | Y | 体裁 |
| org | str | Y | 报备机构 |
| report_date | str | Y | 报备时间 |
| license_key | str | Y | 许可证号 |
| episodes | str | Y | 集数 |
| shooting_date | str | Y | 拍摄时间 |
| prod_cycle | str | Y | 制作周期 |
| content | str | Y | 内容提要 |
| pro_opi | str | Y | 省级管理部门备案意见 |
| dept_opi | str | Y | 相关部门意见 |
| remarks | str | Y | 备注 |

接口使用

```python
pro = ts.pro_api()

#按备案月份查询
df = pro.teleplay_record(report_date='201905')

df = pro.teleplay_record(start_date='201905', end_date='201906')

#按备案机构查询
df = pro.teleplay_record(org='上海新文化传媒集团股份有限公司')

#按电视剧名称查询
df = pro.teleplay_record(name='三体')
```

数据样例

```python
name classify types                 org report_date  license_key  \
0   新大头儿子和小头爸爸Ⅳ     当代青少    喜剧      怡光国际经济文化集团有限公司      201905       甲第260号   
```